Struct
QmiIndicationNasIncrementalNetworkScanOutput
since: 1.38
Description [src]
struct QmiIndicationNasIncrementalNetworkScanOutput {
/* No available fields */
}
The QmiIndicationNasIncrementalNetworkScanOutput structure contains private data and should only be accessed
using the provided API.
Available since: 1.38
Instance methods
qmi_indication_nas_incremental_network_scan_output_get_network_information
Get the ‘Network Information’ field from self.
since: 1.38
qmi_indication_nas_incremental_network_scan_output_get_network_information_gir
Get the ‘Network Information’ field from self.
since: 1.38
qmi_indication_nas_incremental_network_scan_output_get_status
Get the ‘Status’ field from self.
since: 1.38
qmi_indication_nas_incremental_network_scan_output_ref
Atomically increments the reference count of self by one.
since: 1.38
qmi_indication_nas_incremental_network_scan_output_unref
Atomically decrements the reference count of self by one.
If the reference count drops to 0, self is completely disposed.
since: 1.38